pub enum RenderPassCommand<'a> {
SetScissor {
top_left: [u32; 2],
dimensions: [u32; 2],
},
Draw {
vertex_range: Range<u32>,
},
SetBindGroup {
bind_group: &'a BindGroup,
},
SetPipeline {
pipeline: &'a RenderPipeline,
},
}Expand description
A draw command that maps directly to the wgpu::CommandEncoder method. By returning
RenderPassCommands, we can avoid consuming the entire AutoCommandBufferBuilder itself which might
not always be available from APIs that wrap Vulkan.
Variants
SetScissor
Specify the rectangle to which drawing should be cropped.
Draw
Draw the specified range of vertices.
SetBindGroup
A new image requires drawing and in turn a new bind group requires setting.
SetPipeline
An image requiring a different bind group layout requires drawing and in turn, we must set the necessary render pipeline.
Fields

pipeline: &'a RenderPipelineAuto Trait Implementations
impl<'a> Freeze for RenderPassCommand<'a>
impl<'a> !RefUnwindSafe for RenderPassCommand<'a>
impl<'a> Send for RenderPassCommand<'a>
impl<'a> Sync for RenderPassCommand<'a>
impl<'a> Unpin for RenderPassCommand<'a>
impl<'a> UnsafeUnpin for RenderPassCommand<'a>
impl<'a> !UnwindSafe for RenderPassCommand<'a>